Autocompleter — BCI-Framework documentation

# Autocompleter

Auxiliar pop-up list of options with frequent use snippets and methods.

class `bci_framework.framework.editor.completer.` `Autocompleter`(mode: Literal[stimuli, visualization, analysis], parent=None)

  Autocompleter for Python Scripts.

  Parameters

    - mode – The available options are different form stimuli delivery and data analysis.

    - parent –

  `changeCompletion`(completion: str) → None

    Update list options.

  `changeHighlighted`(value: str) → None

    Retain the last option selected.